:html_theme.sidebar_secondary.remove:

EEGDASH Documentation
=====================

.. title:: EEG Dash

.. raw:: html

    <style type="text/css">h1 {display:none;}</style>

EEG Dash Homepage
==================

.. image:: _static/logos/eegdash.png
   :alt: EEG Dash Logo
   :class: logo mainlogo
   :align: center
   :scale: 40%


.. rst-class:: h4 text-center font-weight-light my-4

The EEG-DaSh data archive will establish a data-sharing resource for MEEG (EEG, MEG) data, enabling 
large-scale computational advancements to preserve and share scientific data from publicly funded 
research for machine learning and deep learning applications.

The EEG-DaSh data archive is a collaborative effort led by the University of California, San Diego (UCSD) and Ben-Gurion University of the Negev (BGU) and partially funded by the National Science Foundation (NSF). All are welcome to contribute to the https://github.com/sccn/EEGDash project.

The archive is currently still in :bdg-danger:`beta testing` mode, so be kind. 

.. raw:: html

    <h2 style="text-align: center;">Institutions</h2>


.. list-table::
   :width: 100%
   :class: borderless logos-row

   * - .. image:: _static/logos/ucsd_white.png
         :alt: University of California, San Diego (UCSD)
         :class: logo mainlogo
         :align: center
         :width: 100%
         
     - .. image:: _static/logos/bgu_white.png
         :alt: Ben-Gurion University of the Negev (BGU)
         :class: logo mainlogo
         :align: center
         :width: 100%

.. toctree::
   :hidden:

   Overview <overview>
   Install <install/install>
   API <api/modules.rst>
   Dataset Summary <dataset_summary>
   Examples <generated/auto_examples/index>

